@@ -92,8 +92,7 @@ class ProxyManager:
             for address in addresses:
                 info_list.append(ProxyInfo(protocol, address))
 
-        random.shuffle(info_list)
-        return ProxyPool(self.success_rate, info_list)
+        return ProxyPool(self._test_url, self.success_rate, info_list)
 
     def _on_success(self):
         with self._metrics_lock:
