@@ -17,4 +17,7 @@ class SimpleTimer:
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        self._time_elapsed = time.time() - self._enter_time
+        if exc_type is not None:
+            self._time_elapsed = 999.0
+        else:
+            self._time_elapsed = time.time() - self._enter_time
